@@ -4,14 +4,7 @@ obtained from radheef.mv.
 ބަސްތަކުގެ ލިސްޓާއި ބަސްތަކުގެ މާނަ ހޯދުން
 """
 
-import sqlite3
-import pkg_resources
-
-
-def _db_connect():
-    db_path = pkg_resources.resource_filename("dhivehi_nlp", "data/dhivehi_nlp.db")
-    con = sqlite3.connect(db_path)
-    return con
+from dhivehi_nlp._helpers import _db_connect
 
 
 def get_definition(word: str) -> str:
@@ -33,7 +26,7 @@ def get_definition(word: str) -> str:
     return definition[0]
 
 
-def get_wordlist():
+def get_wordlist() -> list:
     """Returns a list of all the Dhivehi words in the radheef (dictionary).
 
     ހުރިހާ ބަސްތަކެއްގެ ލިސްޓެއް އަނބުރާ ދޭނެއެވެ
